(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[3236],{30527:function(t){"use strict";function a(t){t.languages.roboconf={comment:/#.*/,keyword:{pattern:/(^|\s)(?:(?:facet|instance of)(?=[ \t]+[\w-]+[ \t]*\{)|(?:external|import)\b)/,lookbehind:!0},component:{pattern:/[\w-]+(?=[ \t]*\{)/,alias:"variable"},property:/[\w.-]+(?=[ \t]*:)/,value:{pattern:/(=[ \t]*)[^,;]+/,lookbehind:!0,alias:"attr-value"},optional:{pattern:/\(optional\)/,alias:"builtin"},wildcard:{pattern:/(\.)\*/,lookbehind:!0,alias:"operator"},punctuation:/[{},.;:=]/}}t.exports=a,a.displayName="roboconf",a.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_roboconf.e08f0bedda8a672fe26f.js.map