(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[6495],{14970:function(t){"use strict";function n(t){t.languages.ini={comment:/^[ \t]*[;#].*$/m,selector:/^[ \t]*\[.*?\]/m,constant:/^[ \t]*[^\s=]+?(?=[ \t]*=)/m,"attr-value":{pattern:/=.*/,inside:{punctuation:/^[=]/}}}}t.exports=n,n.displayName="ini",n.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_ini.7a580779e818c6d0e485.js.map