/* TODO: harcoded string that should be translatable/customizable */
export const TITLE_TEXT = 'Amundsen Resource Request';
export const FROM_LABEL = 'From';
export const TO_LABEL = 'To';
export const REQUEST_TYPE = 'Request Type';
export const TABLE_DESCRIPTION = 'Table Description';
export const COLUMN_DESCRIPTIONS = 'Column Descriptions';
export const ADDITIONAL_DETAILS = 'Additional Details';
export const SEND_BUTTON = 'Send Request';

export const SEND_INPROGRESS_MESSAGE = 'Your request is being sent...';
export const SEND_FAILURE_MESSAGE =
  'Your request was not successfully sent, please try again';
export const SEND_SUCCESS_MESSAGE = 'Your request has been successfully sent';

export const RECIPIENT_LIST_DELIMETER = ', ';

export const COMMENT_PLACEHOLDER_DEFAULT =
  'Please enter more information about your request';
export const COMMENT_PLACEHOLDER_COLUMN =
  'Please enter which column(s) need an improved description';

export const COLUMN_REQUESTED_COMMENT_PREFIX =
  'Description requested for column: ';

export const CLOSE = 'Close';
