# Copyright Contributors to the Amundsen project.
# SPDX-License-Identifier: Apache-2.0


class MailClientNotImplemented(Exception):
    """
    An exception when Mail Client is not implemented
    """
    pass
