(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[9770],{3623:function(e){"use strict";function a(e){e.languages.processing=e.languages.extend("clike",{keyword:/\b(?:break|catch|case|class|continue|default|else|extends|final|for|if|implements|import|new|null|private|public|return|static|super|switch|this|try|void|while)\b/,operator:/<[<=]?|>[>=]?|&&?|\|\|?|[%?]|[!=+\-*\/]=?/}),e.languages.insertBefore("processing","number",{constant:/\b(?!XML\b)[A-Z][A-Z\d_]+\b/,type:{pattern:/\b(?:boolean|byte|char|color|double|float|int|XML|[A-Z]\w*)\b/,alias:"variable"}}),e.languages.processing.function.pattern=/\w+(?=\s*\()/,e.languages.processing["class-name"].alias="variable"}e.exports=a,a.displayName="processing",a.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_processing.a516ca616d7f2615f7ce.js.map