// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

// Amundsen Default Typography
@import 'typography-default';
// Per-Client Custom Typography
@import 'typography-custom';
