(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[4045],{82707:function(n){"use strict";function t(n){n.languages.prolog={comment:[/%.+/,/\/\*[\s\S]*?\*\//],string:{pattern:/(["'])(?:\1\1|\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},builtin:/\b(?:fx|fy|xf[xy]?|yfx?)\b/,variable:/\b[A-Z_]\w*/,function:/\b[a-z]\w*(?:(?=\()|\/\d+)/,number:/\b\d+\.?\d*/,operator:/[:\\=><\-?*@\/;+^|!$.]+|\b(?:is|mod|not|xor)\b/,punctuation:/[(){}\[\],]/}}n.exports=t,t.displayName="prolog",t.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_prolog.78266cc879f17db4b091.js.map