export const POPULAR_TAGS_TITLE = 'Popular Tags';
export const CURATED_TAGS_TITLE = 'Curated Tags';
export const OTHER_TAGS_TITLE = 'Other Tags';
export const BROWSE_TAGS_TITLE = 'Browse Tags';
export const BROWSE_MORE_TAGS_TEXT = 'Browse all tags';
export const BROWSE_PAGE_PATH = '/browse';
