// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

// This file is intentionally left blank and should be used to add new custom variables or overwrite defaults from _variables-default.scss
