export const allTestTags = [
  { tag_name: 'test test', tag_count: 3 },
  { tag_name: 'tao_test', tag_count: 1 },
  { tag_name: 'real-time', tag_count: 90 },
  { tag_name: 'tnt-feature', tag_count: 1 },
  { tag_name: 'test12', tag_count: 1 },
  { tag_name: 'xtest12', tag_count: 1 },
  { tag_name: 'ttannis2', tag_count: 2 },
  { tag_name: 'example', tag_count: 4 },
  { tag_name: 'audience-feature', tag_count: 1 },
  { tag_name: 'jinchangtest', tag_count: 1 },
  { tag_name: 'dispatch', tag_count: 1 },
  { tag_name: 'test9', tag_count: 48 },
  { tag_name: 'test2', tag_count: 2 },
  { tag_name: 'test5', tag_count: 14 },
  { tag_name: 'test', tag_count: 3 },
  { tag_name: 'test4', tag_count: 33 },
  { tag_name: 'testing', tag_count: 26 },
  { tag_name: 'support', tag_count: 51 },
  { tag_name: 'abc', tag_count: 4 },
  { tag_name: 'eta', tag_count: 27 },
  { tag_name: 'is testing', tag_count: 2 },
  { tag_name: 'tamika', tag_count: 6 },
  { tag_name: 'passenger-feature', tag_count: 1 },
  { tag_name: 'foobar', tag_count: 11 },
  { tag_name: 'fraud1', tag_count: 83 },
  { tag_name: 'new_tag', tag_count: 2 },
  { tag_name: 'testing2', tag_count: 1 },
  { tag_name: 'test*', tag_count: 1 },
  { tag_name: 'test_table', tag_count: 1 },
  { tag_name: 'invalid', tag_count: 2 },
  { tag_name: 'newtag2', tag_count: 4 },
  { tag_name: 'trips', tag_count: 45 },
  { tag_name: 'newvalue3', tag_count: 1 },
  { tag_name: 'pax', tag_count: 17 },
  { tag_name: 'ride', tag_count: 22 },
  { tag_name: 'fraud', tag_count: 7 },
  { tag_name: 'lbs', tag_count: 9 },
  { tag_name: 'communications', tag_count: 1 },
  { tag_name: 'perf', tag_count: 2 },
  { tag_name: 'a6n', tag_count: 2 },
  { tag_name: 'integration_test', tag_count: 1 },
  { tag_name: 'amundsen', tag_count: 3 },
  { tag_name: 'test1', tag_count: 1 },
  { tag_name: 'tbs', tag_count: 13 },
  { tag_name: 'acquisition', tag_count: 1 },
  { tag_name: 'newtag', tag_count: 1 },
  { tag_name: 'new_tag2', tag_count: 1 },
  { tag_name: 'bar', tag_count: 1 },
  { tag_name: 'test2 test 2', tag_count: 3 },
  { tag_name: 'test test2', tag_count: 2 },
  { tag_name: 'hive', tag_count: 1 },
  { tag_name: 'client', tag_count: 2 },
  { tag_name: 'hive1', tag_count: 4 },
  { tag_name: 'passenger', tag_count: 8 },
  { tag_name: 'tracking', tag_count: 1 },
  { tag_name: 'hello test', tag_count: 5 },
  { tag_name: 'newvalue', tag_count: 86 },
  { tag_name: 'foo', tag_count: 42 },
  { tag_name: 'bike', tag_count: 10 },
  { tag_name: 'engagement', tag_count: 1 },
  { tag_name: 'driver', tag_count: 2 },
  { tag_name: 'ml-platform', tag_count: 5 },
  { tag_name: 'event', tag_count: 1 },
  { tag_name: 'tracking-event', tag_count: 21 },
  { tag_name: 'finance', tag_count: 9 },
  { tag_name: 'newValue2', tag_count: 2 },
  { tag_name: 'regions', tag_count: 16 },
  { tag_name: 'coco', tag_count: 15 },
  { tag_name: 'tagger', tag_count: 1 },
  { tag_name: 'amundsen-test', tag_count: 3 },
  { tag_name: 'dp-tools', tag_count: 2 },
];
