(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[5539],{61321:function(a){"use strict";function e(a){a.languages.brainfuck={pointer:{pattern:/<|>/,alias:"keyword"},increment:{pattern:/\+/,alias:"inserted"},decrement:{pattern:/-/,alias:"deleted"},branching:{pattern:/\[|\]/,alias:"important"},operator:/[.,]/,comment:/\S+/}}a.exports=e,e.displayName="brainfuck",e.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_brainfuck.4619f5542f183d88b02d.js.map