# Copyright Contributors to the Amundsen project.
# SPDX-License-Identifier: Apache-2.0


class IssueConfigurationException(Exception):
    """
    Raised when there are missing configuration settings
    """
    pass
