export const REPORT_DATA_ISSUE_TEXT = 'Report an issue';
export const TABLE_OWNERS_NOTE =
  'Please note: Table owners will also be notified via email when an issue is reported.';
export const CLOSE = 'Close';
