// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

import '../css/styles.scss';

const categoriesOrder = ['Overview', 'Attributes', 'Components'];

export const parameters = {
  options: {
    storySort: {
      order: categoriesOrder,
    },
  },
};
