(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[1438],{60274:function(t){"use strict";function a(t){t.languages.arff={comment:/%.*/,string:{pattern:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/@(?:attribute|data|end|relation)\b/i,number:/\b\d+(?:\.\d+)?\b/,punctuation:/[{},]/}}t.exports=a,a.displayName="arff",a.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_arff.85a7aee19a841af066a8.js.map