export const AVATAR_SIZE = 40;

export const BOOKMARKED_LABEL = 'bookmarked';
export const BOOKMARKED_SOURCE = 'profile_bookmark';
export const BOOKMARKED_TITLE_PREFIX = 'Bookmarked';

export const ITEMS_PER_PAGE = 3;

export const OWNED_LABEL = 'owned';
export const OWNED_SOURCE = 'profile_own';
export const OWNED_TITLE_PREFIX = 'Owned';

export const READ_LABEL = 'frequently used';
export const READ_SOURCE = 'profile_read';
export const READ_TITLE_PREFIX = 'Frequently Used';
export const PROFILE_TEXT = 'Employee Profile';
export const GITHUB_LINK_TEXT = 'Github';

export const EMPTY_TEXT_PREFIX = 'User has no';
export const FOOTER_TEXT_PREFIX = 'View all';

export const NOT_ACTIVE_USER_TEXT = 'Alumni';
