(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[3140],{60561:function(a){"use strict";function s(a){a.languages.hsts={directive:{pattern:/\b(?:max-age=|includeSubDomains|preload)/,alias:"keyword"},safe:{pattern:/\d{8,}/,alias:"selector"},unsafe:{pattern:/\d{1,7}/,alias:"function"}}}a.exports=s,s.displayName="hsts",s.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_hsts.703b0162fe15ce934865.js.map