// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

@import 'variables';

.entity-card {
  border-radius: 0 0 6px 6px;
  border-top: 4px solid $brand-color-4;
  box-shadow: 0 0 24px -2px rgba(0, 0, 0, 0.2);
  padding: 32px;
}

@media (max-width: $screen-sm-max) {
  .entity-card {
    border: 0;
    box-shadow: none;
    margin-bottom: 32px;
    padding: 0;
  }
}
