(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[6247],{93336:function(e){"use strict";function a(e){!function(e){e.languages.diff={coord:[/^(?:\*{3}|-{3}|\+{3}).*$/m,/^@@.*@@$/m,/^\d+.*$/m]};var a={"deleted-sign":"-","deleted-arrow":"<","inserted-sign":"+","inserted-arrow":">",unchanged:" ",diff:"!"};Object.keys(a).forEach((function(s){var n=a[s],t=[];/^\w+$/.test(s)||t.push(/\w+/.exec(s)[0]),"diff"===s&&t.push("bold"),e.languages.diff[s]={pattern:RegExp("^(?:["+n+"].*(?:\r\n?|\n|(?![\\s\\S])))+","m"),alias:t}})),Object.defineProperty(e.languages.diff,"PREFIXES",{value:a})}(e)}e.exports=a,a.displayName="diff",a.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_diff.e7e530ef909bd3b79e83.js.map