/* TODO: harcoded string that should be translatable/customizable */
/* Form */
export const BUTTON_CLOSE_TEXT = 'Close';
export const FEEDBACK_TITLE = 'Product Feedback';
export const SUBMIT_FAILURE_MESSAGE =
  'Your feedback was not submitted, please try again';
export const SUBMIT_SUCCESS_MESSAGE =
  'Your feedback has been successfully submitted';

/* Button Set */
export const BUG_REPORT_TEXT = 'Bug Report';
export const FEEDBACK_BUTTON_TEXT = 'Give us Feedback';
export const FEEDBACK_TYPE_TEXT = 'Feedback Type Selector';
export const RATING_TEXT = 'Rating';
export const REQUEST_TEXT = 'Request';

/* Nested Forms */
export const BUG_SUMMARY_LABEL = 'Bug Summary';
export const BUG_SUMMARY_PLACEHOLDER = 'What went wrong?';

export const COMMENTS_PLACEHOLDER = 'Additional Comments';

export const FEATURE_SUMMARY_LABEL = 'Feature Summary';
export const FEATURE_SUMMARY_PLACEHOLDER = 'What feature are you requesting?';

export const PROPOSITION_LABEL = 'Value Proposition';
export const PROPOSITION_PLACEHOLDER = 'How does this feature add value?';

export const RATING_LABEL =
  'How likely are you to recommend this tool to a friend or co-worker?';

export const RATING_LOW_TEXT = 'Not Very Likely';
export const RATING_HIGH_TEXT = 'Very Likely';

export const REPRO_STEPS_LABEL = 'Reproduction Steps';
export const REPRO_STEPS_PLACEHOLDER = 'What did you do to encounter this bug?';

export const SUBJECT_LABEL = 'Subject';
export const SUBJECT_PLACEHOLDER = 'Enter a subject';

export const SUBMIT_TEXT = 'Submit';
