(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[81],{56267:function(t){"use strict";function s(t){t.languages.properties={comment:/^[ \t]*[#!].*$/m,"attr-value":{pattern:/(^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+?(?: *[=:] *| ))(?:\\(?:\r\n|[\s\S])|[^\\\r\n])+/m,lookbehind:!0},"attr-name":/^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+?(?= *[=:] *| )/m,punctuation:/[=:]/}}t.exports=s,s.displayName="properties",s.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_properties.205038bf003d1712abf8.js.map