(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[3657],{45950:function(e){"use strict";function n(e){e.languages.json={property:{pattern:/"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,greedy:!0},string:{pattern:/"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,greedy:!0},comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,number:/-?\d+\.?\d*(e[+-]?\d+)?/i,punctuation:/[{}[\],]/,operator:/:/,boolean:/\b(?:true|false)\b/,null:{pattern:/\bnull\b/,alias:"keyword"}}}e.exports=n,n.displayName="json",n.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_json.a9009545676648416748.js.map