// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

@import 'variables';

.entity-card-section {
  margin-bottom: 20px;

  .content-header {
    display: flex;

    .caption {
      flex-grow: 1;
    }
  }

  .content {
    margin-top: 5px;
  }

  .content-header button.edit-button,
  .content-header button.active-edit-button {
    margin-left: 4px;
    margin-top: -4px;
  }

  button.edit-button {
    background-color: $icon-bg;
    border: none;
    border-radius: 5px;
    height: 24px;
    -webkit-mask-image: url('../../../../../images/icons/Edit.svg');
    mask-image: url('../../../../../images/icons/Edit.svg');
    width: 24px;
  }

  button.edit-button:hover {
    background-color: $brand-color-4;
  }

  button.active-edit-button {
    background-color: $brand-color-1;
    background-image: url('../../../../../images/icons/Edit_Inverted.svg');
    border: none;
    border-radius: 5px;
    -moz-box-shadow: inset 1px 1px 2px $brand-color-4;
    -webkit-box-shadow: inset 1px 1px 2px $brand-color-4;
    box-shadow: inset 1px 1px 2px $brand-color-4;
    height: 24px;
    width: 24px;
  }

  button.edit-button:focus,
  button.active-edit-button:focus {
    box-shadow: 0 0 1pt 1pt $brand-color-4;
    outline: none;
  }

  @media (min-width: $screen-md-min) {
    button.edit-button,
    button.active-edit-button {
      float: right;
    }
  }
}
