// TODO: Hard-coded text strings should be translatable/customizable
export const PLACEHOLDER_DEFAULT = 'Search for data resources...';
export const SEARCH_BUTTON_TEXT = 'Search';
export const BUTTON_CLOSE_TEXT = 'Close';

export const SIZE_SMALL = 'small';

export const INVALID_SYNTAX_MESSAGE =
  "Your search term contains invalid syntax ':'.";
