export const ERROR_MESSAGE = 'Something went wrong...';
export const EDIT_DESC_TEXT = 'Click to edit description in';
export const EDIT_OWNERS_TEXT = 'Click to edit owners in';

export const DATE_RANGE_TITLE = 'Date Range';
export const DESCRIPTION_TITLE = 'Description';
export const FREQ_USERS_TITLE = 'Frequent Users';
export const LAST_UPDATED_TITLE = 'Last Updated';
export const OWNERS_TITLE = 'Owners';
export const TAG_TITLE = 'Tags';
export const SORT_BY_DROPDOWN_TITLE = 'Sort by';
export const SORT_BY_MENU_TITLE_TEXT = 'Sort by';
