(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[5299],{65447:function(e){"use strict";function s(e){e.languages.csp={directive:{pattern:/\b(?:(?:base-uri|form-action|frame-ancestors|plugin-types|referrer|reflected-xss|report-to|report-uri|require-sri-for|sandbox) |(?:block-all-mixed-content|disown-opener|upgrade-insecure-requests)(?: |;)|(?:child|connect|default|font|frame|img|manifest|media|object|script|style|worker)-src )/i,alias:"keyword"},safe:{pattern:/'(?:self|none|strict-dynamic|(?:nonce-|sha(?:256|384|512)-)[a-zA-Z\d+=/]+)'/,alias:"selector"},unsafe:{pattern:/(?:'unsafe-inline'|'unsafe-eval'|'unsafe-hashed-attributes'|\*)/,alias:"function"}}}e.exports=s,s.displayName="csp",s.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_csp.f255f7fab49d77fc2d21.js.map