(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[6975],{17290:function(a){"use strict";function n(a){a.languages.tap={fail:/not ok[^#{\n\r]*/,pass:/ok[^#{\n\r]*/,pragma:/pragma [+-][a-z]+/,bailout:/bail out!.*/i,version:/TAP version \d+/i,plan:/\d+\.\.\d+(?: +#.*)?/,subtest:{pattern:/# Subtest(?:: .*)?/,greedy:!0},punctuation:/[{}]/,directive:/#.*/,yamlish:{pattern:/(^[^\S\r\n]*)---(?:\r\n?|\n)(?:.*(?:\r\n?|\n))*?[^\S\r\n]*\.\.\.$/m,lookbehind:!0,inside:a.languages.yaml,alias:"language-yaml"}}}a.exports=n,n.displayName="tap",n.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_tap.3b15e6908829d662f4c5.js.map