// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

@import 'variables';

.flag {
  border-radius: 5px;
  display: inline-block;
  font-size: $font-size-base;
  height: $badge-height;
  margin: 0 0 0 $spacer-1;
}

.label {
  border-radius: 10px;
  font-weight: normal;
}
