<!doctype html><html lang="en-US"><head><meta charset="utf-8"><title>Amundsen - Data Discovery Portal</title><meta name="description" content=""><meta name="viewport" content="width=device-width,initial-scale=1">{% if env == "development" %} {% include 'fragments/icons-dev.html' %} {% elif env == "staging" %} {% include 'fragments/icons-staging.html' %} {% else %} {% include 'fragments/icons-prod.html' %} {% endif %}<script defer="defer" src="/static/dist/vendors.be79274b975c96de053e.js"></script><script defer="defer" src="/static/dist/main.379cfb107c48c1b548df.js"></script><link href="/static/dist/main.8d3568676d6be7c42985.css" rel="stylesheet"><script id="analyitcs-script-stub"></script></head><body class="{{ env }}"><div id="content"/></body></html>