export const ERROR_MESSAGE =
  'Unable to load the dashboard preview image. \
Please view the dashboard at';

export const PREVIEW_BUTTON_TEXT = 'See Dashboard Preview';
export const PREVIEW_BASE = '/api/dashboard_preview/v0/dashboard';
export const PREVIEW_END = 'preview.jpg';

export const DASHBOARD_PREVIEW_MODAL_TITLE = 'Dashboard Preview';
