// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

// TODO - Implement tests for TagInput

describe('TagInput', () => {
  it('Placeholder test', () => {});
});
