export const MORE_BUTTON_TEXT = 'More options';
export const REQUEST_DESCRIPTION_TEXT = 'Request Column Description';
export const EMPTY_MESSAGE = 'There are no available columns for this table';
export const EDITABLE_SECTION_TITLE = 'Description';
export const COLUMN_STATS_TITLE = 'Column Statistics';
