// Copyright Contributors to the Amundsen project.
// SPDX-License-Identifier: Apache-2.0

@import 'variables';

.request-description {
  font-size: 16px;
  text-decoration: none;

  &:hover,
  &:visited,
  &:active,
  &:link {
    text-decoration: none;
  }
}
