<!--
  Copyright Contributors to the Amundsen project.
  SPDX-License-Identifier: Apache-2.0
-->

<!-- Generated with https://realfavicongenerator.net/ -->
<link rel="apple-touch-icon" sizes="180x180" href="/static/images/favicons/prod/apple-touch-icon.png">
<link rel="icon" type="image/png" sizes="32x32" href="/static/images/favicons/prod/favicon-32x32.png">
<link rel="icon" type="image/png" sizes="16x16" href="/static/images/favicons/prod/favicon-16x16.png">
<link rel="manifest" href="/static/images/favicons/prod/site.webmanifest" crossorigin="use-credentials">
<link rel="mask-icon" href="/static/images/favicons/prod/safari-pinned-tab.svg" color="#5bbad5">
<link rel="shortcut icon" href="/static/images/favicons/prod/favicon.ico">
<meta name="msapplication-TileColor" content="#2d89ef">
<meta name="msapplication-config" content="/static/images/favicons/prod/browserconfig.xml">
<meta name="theme-color" content="#ffffff">
