(self.webpackChunkstatic=self.webpackChunkstatic||[]).push([[6749],{76942:function(a){"use strict";function e(a){a.languages.hpkp={directive:{pattern:/\b(?:(?:includeSubDomains|preload|strict)(?: |;)|pin-sha256="[a-zA-Z\d+=/]+"|(?:max-age|report-uri)=|report-to )/,alias:"keyword"},safe:{pattern:/\d{7,}/,alias:"selector"},unsafe:{pattern:/\d{1,6}/,alias:"function"}}}a.exports=e,e.displayName="hpkp",e.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_hpkp.accbba896cdc5823afd5.js.map