export const TABLES_PER_PAGE = 10;
export const DASHBOARD_SOURCE = 'dashboard_page';

export const OWNER_HEADER_TEXT = 'Owners';

export const ADD_DESC_TEXT = 'Add Description in';
export const EDIT_DESC_TEXT = 'Click to edit description in';

export const LAST_RUN_SUCCEEDED = 'succeeded';
export const STATUS_TEXT = 'Status:';
