import { PeopleUser } from 'interfaces/User';

export const activeUser0: PeopleUser = {
  manager_fullname: undefined,
  manager_email: undefined,
  profile_url: '/test0',
  role_name: undefined,
  display_name: '',
  github_username: '',
  team_name: '',
  last_name: '',
  full_name: '',
  slack_id: '',
  first_name: '',
  employee_type: '',
  is_active: true,
  email: 'user0@test.com',
  user_id: 'user0',
};

export const activeUser1: PeopleUser = {
  manager_fullname: undefined,
  manager_email: undefined,
  profile_url: '/test1',
  role_name: undefined,
  display_name: '',
  github_username: '',
  team_name: '',
  last_name: '',
  full_name: '',
  slack_id: '',
  first_name: '',
  employee_type: '',
  is_active: true,
  email: 'user10@test.com',
  user_id: 'user1',
};
